@@ -1,9 +1,8 @@
 from abc import *
 
 
-class User:
+class User(metaclass=ABCMeta):
     ''' User interface '''
-    __metaclass__ = ABCMeta
 
     def __init__(self, username):
         self.username = username
@@ -35,13 +34,12 @@ class User:
         pass
 
 
-class Recipe:
-    __metaclass__ = ABCMeta
+class Recipe(metaclass=ABCMeta):
+    pass
 
 
-class Package(Recipe):
+class Package(Recipe, metaclass=ABCMeta):
     ''' Package interface '''
-    __metaclass__ = ABCMeta
     dependencies = ()
     name = None
 
